diff --git a/src/components/structures/RoomDirectory.js b/src/components/structures/RoomDirectory.js
index c18dd4d48a..3fb2cc86ef 100644
--- a/src/components/structures/RoomDirectory.js
+++ b/src/components/structures/RoomDirectory.js
@@ -96,9 +96,9 @@ module.exports = React.createClass({
return;
}
const ErrorDialog = sdk.getComponent("dialogs.ErrorDialog");
- Modal.createTrackedDialog('Failed to get protocol list from Home Server', '', ErrorDialog, {
- title: _t('Failed to get protocol list from Home Server'),
- description: _t('The Home Server may be too old to support third party networks'),
+ Modal.createTrackedDialog('Failed to get protocol list from homeserver', '', ErrorDialog, {
+ title: _t('Failed to get protocol list from homeserver'),
+ description: _t('The homeserver may be too old to support third party networks'),
});
});
diff --git a/src/components/structures/RoomView.js b/src/components/structures/RoomView.js
index 01df8272fa..26ef3da739 100644
--- a/src/components/structures/RoomView.js
+++ b/src/components/structures/RoomView.js
@@ -78,7 +78,7 @@ module.exports = React.createClass({
// * invitedEmail (string) The email address that was invited to this room
thirdPartyInvite: PropTypes.object,
- // Any data about the room that would normally come from the Home Server
+ // Any data about the room that would normally come from the homeserver
// but has been passed out-of-band, eg. the room name and avatar URL
// from an email invite (a workaround for the fact that we can't
// get this information from the HS using an email invite).
diff --git a/src/components/views/auth/CaptchaForm.js b/src/components/views/auth/CaptchaForm.js
index 01715b397c..ca450c5df4 100644
--- a/src/components/views/auth/CaptchaForm.js
+++ b/src/components/views/auth/CaptchaForm.js
@@ -141,7 +141,7 @@ module.exports = React.createClass({
return (
- { _t("This Home Server would like to make sure you are not a robot") }
+ { _t("This homeserver would like to make sure you are not a robot.") }
{ error }
diff --git a/src/components/views/settings/DevicesPanel.js b/src/components/views/settings/DevicesPanel.js
index 25850819bd..1f502fac2f 100644
--- a/src/components/views/settings/DevicesPanel.js
+++ b/src/components/views/settings/DevicesPanel.js
@@ -61,7 +61,7 @@ export default class DevicesPanel extends React.Component {
let errtxt;
if (error.httpStatus == 404) {
// 404 probably means the HS doesn't yet support the API.
- errtxt = _t("Your home server does not support device management.");
+ errtxt = _t("Your homeserver does not support device management.");
} else {
console.error("Error loading devices:", error);
errtxt = _t("Unable to load device list");
diff --git a/src/i18n/strings/en_EN.json b/src/i18n/strings/en_EN.json
index fd56965470..e3fced8e7f 100644
--- a/src/i18n/strings/en_EN.json
+++ b/src/i18n/strings/en_EN.json
@@ -41,7 +41,7 @@
"Permission Required": "Permission Required",
"You do not have permission to start a conference call in this room": "You do not have permission to start a conference call in this room",
"The file '%(fileName)s' failed to upload": "The file '%(fileName)s' failed to upload",
- "The file '%(fileName)s' exceeds this home server's size limit for uploads": "The file '%(fileName)s' exceeds this home server's size limit for uploads",
+ "The file '%(fileName)s' exceeds this homeserver's size limit for uploads": "The file '%(fileName)s' exceeds this homeserver's size limit for uploads",
"Upload Failed": "Upload Failed",
"Failure to create room": "Failure to create room",
"Server may be unavailable, overloaded, or you hit a bug.": "Server may be unavailable, overloaded, or you hit a bug.",
@@ -352,7 +352,7 @@
"New Password": "New Password",
"Confirm password": "Confirm password",
"Change Password": "Change Password",
- "Your home server does not support device management.": "Your home server does not support device management.",
+ "Your homeserver does not support device management.": "Your homeserver does not support device management.",
"Unable to load device list": "Unable to load device list",
"Authentication": "Authentication",
"Delete %(count)s devices|other": "Delete %(count)s devices",
@@ -1178,7 +1178,7 @@
"Login": "Login",
"powered by Matrix": "powered by Matrix",
"Robot check is currently unavailable on desktop - please use a
web browser": "Robot check is currently unavailable on desktop - please use a
web browser",
- "This Home Server would like to make sure you are not a robot": "This Home Server would like to make sure you are not a robot",
+ "This homeserver would like to make sure you are not a robot.": "This homeserver would like to make sure you are not a robot.",
"Custom Server Options": "Custom Server Options",
"You can use the custom server options to sign into other Matrix servers by specifying a different homeserver URL. This allows you to use this app with an existing Matrix account on a different homeserver.": "You can use the custom server options to sign into other Matrix servers by specifying a different homeserver URL. This allows you to use this app with an existing Matrix account on a different homeserver.",
"You can also set a custom identity server, but you won't be able to invite users by email address, or be invited by email address yourself.": "You can also set a custom identity server, but you won't be able to invite users by email address, or be invited by email address yourself.",
@@ -1273,7 +1273,7 @@
"Long Description (HTML)": "Long Description (HTML)",
"Description": "Description",
"Community %(groupId)s not found": "Community %(groupId)s not found",
- "This Home server does not support communities": "This Home server does not support communities",
+ "This homeserver does not support communities": "This homeserver does not support communities",
"Failed to load %(groupId)s": "Failed to load %(groupId)s",
"Couldn't load home page": "Couldn't load home page",
"You are currently using Riot anonymously as a guest.": "You are currently using Riot anonymously as a guest.",
@@ -1301,8 +1301,8 @@
"Create a new community": "Create a new community",
"Create a community to group together users and rooms! Build a custom homepage to mark out your space in the Matrix universe.": "Create a community to group together users and rooms! Build a custom homepage to mark out your space in the Matrix universe.",
"You have no visible notifications": "You have no visible notifications",
- "Failed to get protocol list from Home Server": "Failed to get protocol list from Home Server",
- "The Home Server may be too old to support third party networks": "The Home Server may be too old to support third party networks",
+ "Failed to get protocol list from homeserver": "Failed to get protocol list from homeserver",
+ "The homeserver may be too old to support third party networks": "The homeserver may be too old to support third party networks",
"Failed to get public room list": "Failed to get public room list",
"The server may be unavailable or overloaded": "The server may be unavailable or overloaded",
"Delete the room alias %(alias)s and remove %(name)s from the directory?": "Delete the room alias %(alias)s and remove %(name)s from the directory?",
@@ -1399,11 +1399,11 @@
"Invalid homeserver discovery response": "Invalid homeserver discovery response",
"Invalid identity server discovery response": "Invalid identity server discovery response",
"General failure": "General failure",
- "This Home Server does not support login using email address.": "This Home Server does not support login using email address.",
+ "This homeserver does not support login using email address.": "This homeserver does not support login using email address.",
"Please
contact your service administrator to continue using this service.": "Please
contact your service administrator to continue using this service.",
"Incorrect username and/or password.": "Incorrect username and/or password.",
"Please note you are logging into the %(hs)s server, not matrix.org.": "Please note you are logging into the %(hs)s server, not matrix.org.",
- "Guest access is disabled on this Home Server.": "Guest access is disabled on this Home Server.",
+ "Guest access is disabled on this homeserver.": "Guest access is disabled on this homeserver.",
"Failed to perform homeserver discovery": "Failed to perform homeserver discovery",
"The phone number entered looks invalid": "The phone number entered looks invalid",
"Unknown failure discovering homeserver": "Unknown failure discovering homeserver",
diff --git a/src/components/structures/auth/Login.js b/src/components/structures/auth/Login.js
index d1b0aad31a..c5e07aed5a 100644
--- a/src/components/structures/auth/Login.js
+++ b/src/components/structures/auth/Login.js
@@ -63,7 +63,7 @@ module.exports = React.createClass({
defaultIsUrl: PropTypes.string,
// Secondary HS which we try to log into if the user is using
// the default HS but login fails. Useful for migrating to a
// different home server without confusing users.
fallbackHsUrl: PropTypes.string,
// An error passed along from higher up explaining that something
@@ -160,7 +160,7 @@ module.exports = React.createClass({
// Some error strings only apply for logging in
const usingEmail = username.indexOf("@") > 0;
if (error.httpStatus === 400 && usingEmail) {
- errorText = _t('This Home Server does not support login using email address.');
+ errorText = _t('This homeserver does not support login using email address.');
} else if (error.errcode == 'M_RESOURCE_LIMIT_EXCEEDED') {
const errorTop = messageForResourceLimitError(
error.data.limit_type,
@@ -241,7 +241,7 @@ module.exports = React.createClass({
}, function(error) {
let errorText;
if (error.httpStatus === 403) {
- errorText = _t("Guest access is disabled on this Home Server.");
+ errorText = _t("Guest access is disabled on this homeserver.");
} else {
errorText = self._errorTextFromError(error);
}
@@ -63,7 +63,7 @@ module.exports = React.createClass({
// Secondary HS which we try to log into if the user is using
// the default HS but login fails. Useful for migrating to a
- // different home server without confusing users.
+ // different homeserver without confusing users.
fallbackHsUrl: PropTypes.string,
// An error passed along from higher up explaining that something